# lazyloads  
Python package for extra functions in builtin data types including:  
-  list  
-  dict  
-  string  
-  int  
-  float  

## Installing lazyloads  
`pip install lazyloads`    
or     
`python3 -m pip install lazyloads`  

## Install requirements  
Python >= 3.5  

## Includes  
- [lzlist](docs/documentation.md/#lzlist-object)  
- [lzstr](docs/documentation.md/#lzstr-object)  
- [lzdict](docs/documentation.md/#lzdict-object)  
- [lzint](docs/documentation.md/#lzint-object)  
- [lzfloat](docs/documentation.md/#lzfloat-object)  
  
## How to import 
```python
import lzl
```
For more functions and docs, visit [here](docs/documentation.md/)

## Unexpected errors
Please open an issue for any errors encountered.   

Thank you!  
###### lazyloads, a python module to make your life easier  
###### © 2020 Matthew Lam